@@ -46,38 +46,37 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnome/libgnome.h>
+#include <libgnomeui/gnome-help.h>
 #include <libgnomeui/gnome-about.h>
 #include <libgnomeui/gnome-window-icon.h>
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
-#include <egg-screen-exec.h>
-#include <egg-screen-help.h>
 
 #ifdef HAVE_LINUX_SOUNDCARD_H
 #include <linux/soundcard.h>
 #define OSS_API
-#elif HAVE_MACHINE_SOUNDCARD_H
+#elif defined HAVE_MACHINE_SOUNDCARD_H
 #include <machine/soundcard.h>
 #define OSS_API
-#elif HAVE_SYS_SOUNDCARD_H
+#elif defined HAVE_SYS_SOUNDCARD_H
 #include <sys/soundcard.h>
 #define OSS_API
-#elif HAVE_SOUNDCARD_H
+#elif defined HAVE_SOUNDCARD_H
 #include <soundcard.h>
 #define OSS_API
-#elif HAVE_SYS_AUDIOIO_H
+#elif defined HAVE_SYS_AUDIOIO_H
 #include <sys/audioio.h>
 #define SUN_API
-#elif HAVE_SYS_AUDIO_IO_H
+#elif defined HAVE_SYS_AUDIO_IO_H
 #include <sys/audio.io.h>
 #define SUN_API
-#elif HAVE_SUN_AUDIOIO_H
+#elif defined HAVE_SUN_AUDIOIO_H
 #include <sun/audioio.h>
 #define SUN_API
-#elif HAVE_DMEDIA_AUDIO_H
+#elif defined HAVE_DMEDIA_AUDIO_H
 #define IRIX_API
 #include <dmedia/audio.h>
-#elif HAVE_GSTREAMER
+#elif defined HAVE_GSTREAMER
 #define GSTREAMER_API
 #include <gst/gst.h>
 #include <gst/mixer/mixer.h>
@@ -1250,6 +1249,8 @@ destroy_mixer_cb (GtkWidget *widget, MixerData *data)
 		gtk_widget_destroy (data->error_dialog);
 	if (data->tooltips)
 		g_object_unref (data->tooltips);
+	if (data->device)
+		g_free (data->device);
 	g_free (data);
 }
 
@@ -1355,7 +1356,7 @@ mixer_about_cb (BonoboUIComponent *uic,
                 return;
         }
         
-        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mixer/gnome-mixer-applet.png", TRUE, NULL);
+        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mixer-applet.png", TRUE, NULL);
         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
         g_free (file);
 
@@ -1374,7 +1375,7 @@ mixer_about_cb (BonoboUIComponent *uic,
 
 	gtk_window_set_wmclass (GTK_WINDOW(data->about_dialog), "volume control", "Volume Control");
 
-	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
+	gnome_window_icon_set_from_file (GTK_WINDOW (data->about_dialog), GNOME_ICONDIR "gnome-mixer-applet.png");
         
 	g_signal_connect (G_OBJECT (data->about_dialog), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
@@ -1390,7 +1391,7 @@ mixer_help_cb (BonoboUIComponent *uic,
 {
         GError *error = NULL;
 
-	egg_help_display_on_screen (
+	gnome_help_display_on_screen (
 		"mixer_applet2", NULL,
 		gtk_widget_get_screen (data->applet),
 		&error);
@@ -1445,7 +1446,7 @@ show_help_cb (GtkWindow *dialog)
      						      GNOME_PROGRAM_STANDARD_PROPERTIES, NULL);
 	}
 
-	egg_help_display_desktop_on_screen (
+	gnome_help_display_desktop_on_screen (
 			applet_program, "mixer_applet2", "mixer_applet2", NULL,
 			gtk_widget_get_screen (GTK_WIDGET (dialog)),
 			&error);
@@ -1513,7 +1514,7 @@ mixer_pref_cb (BonoboUIComponent *uic,
                                                    GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
                                                    GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                                    NULL);
-	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");	
+	gnome_window_icon_set_from_file (GTK_WINDOW (dialog), GNOME_ICONDIR "gnome-mixer-applet.png");	
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_window_set_screen (GTK_WINDOW (dialog),
@@ -1770,7 +1771,7 @@ register_mixer_stock_icons (GtkIconFactory *factory)
 }
 
 static void
-mixer_init_stock_icons ()
+mixer_init_stock_icons (void)
 {
 	GtkIconFactory *factory;
 	
